0.9.9 API documentation: GLM_GTX_transform2

| 0.9.9 API documentation

- Main Page
- Modules
- Files

Functions
GLM_GTX_transform2
Experimental extensions

Include <glm/gtx/transform2.hpp> to use the features of this extension. More...

## Functions
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 3, 3, T, Q > | proj2D (mat< 3, 3, T, Q > const &m, vec< 3, T, Q > const &normal)
| Build planar projection matrix along normal axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | proj3D (mat< 4, 4, T, Q > const &m, vec< 3, T, Q > const &normal)
| Build planar projection matrix along normal axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | scaleBias (T scale, T bias)
| Build a scale bias matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | scaleBias (mat< 4, 4, T, Q > const &m, T scale, T bias)
| Build a scale bias matrix. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 3, 3, T, Q > | shearX2D (mat< 3, 3, T, Q > const &m, T y)
| Transforms a matrix with a shearing on X axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | shearX3D (mat< 4, 4, T, Q > const &m, T y, T z)
| Transforms a matrix with a shearing on X axis From GLM_GTX_transform2 extension. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 3, 3, T, Q > | shearY2D (mat< 3, 3, T, Q > const &m, T x)
| Transforms a matrix with a shearing on Y axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | shearY3D (mat< 4, 4, T, Q > const &m, T x, T z)
| Transforms a matrix with a shearing on Y axis. More...
template<typename T , qualifier Q>
GLM_FUNC_DECL mat< 4, 4, T, Q > | shearZ3D (mat< 4, 4, T, Q > const &m, T x, T y)
| Transforms a matrix with a shearing on Z axis. More...

## Detailed Description

Include <glm/gtx/transform2.hpp> to use the features of this extension.

Add extra transformation matrices

## Function Documentation

GLM_FUNC_DECL mat<3, 3, T, Q> glm::proj2D | ( | mat< 3, 3, T, Q > const & | m,
|  | vec< 3, T, Q > const & | normal
| ) |  |

Build planar projection matrix along normal axis.

From GLM_GTX_transform2 extension.

GLM_FUNC_DECL mat<4, 4, T, Q> glm::proj3D | ( | mat< 4, 4, T, Q > const & | m,
|  | vec< 3, T, Q > const & | normal
| ) |  |

Build planar projection matrix along normal axis.

From GLM_GTX_transform2 extension.

GLM_FUNC_DECL mat<4, 4, T, Q> glm::scaleBias | ( | T | scale,
|  | T | bias
| ) |  |

Build a scale bias matrix.

From GLM_GTX_transform2 extension.

GLM_FUNC_DECL mat<4, 4, T, Q> glm::scaleBias | ( | mat< 4, 4, T, Q > const & | m,
|  | T | scale,
|  | T | bias
| ) |  |

Build a scale bias matrix.

From GLM_GTX_transform2 extension.

GLM_FUNC_DECL mat<3, 3, T, Q> glm::shearX2D | ( | mat< 3, 3, T, Q > const & | m,
|  | T | y
| ) |  |

Transforms a matrix with a shearing on X axis.

From GLM_GTX_transform2 extension.

GLM_FUNC_DECL mat<4, 4, T, Q> glm::shearX3D | ( | mat< 4, 4, T, Q > const & | m,
|  | T | y,
|  | T | z
| ) |  |

Transforms a matrix with a shearing on X axis From GLM_GTX_transform2 extension.

GLM_FUNC_DECL mat<3, 3, T, Q> glm::shearY2D | ( | mat< 3, 3, T, Q > const & | m,
|  | T | x
| ) |  |

Transforms a matrix with a shearing on Y axis.

From GLM_GTX_transform2 extension.

GLM_FUNC_DECL mat<4, 4, T, Q> glm::shearY3D | ( | mat< 4, 4, T, Q > const & | m,
|  | T | x,
|  | T | z
| ) |  |

Transforms a matrix with a shearing on Y axis.

From GLM_GTX_transform2 extension.

GLM_FUNC_DECL mat<4, 4, T, Q> glm::shearZ3D | ( | mat< 4, 4, T, Q > const & | m,
|  | T | x,
|  | T | y
| ) |  |

Transforms a matrix with a shearing on Z axis.

From GLM_GTX_transform2 extension.